@@ -12,7 +12,7 @@ from traceback import format_exc
 from bson.objectid import ObjectId
 from tornado.web import HTTPError
 from tornado.web import RequestHandler
-from lcyframe.libs import errors
+from lcyframe.libs import Copyright, errors
 from lcyframe.libs import utils
 from lcyframe.libs.funts import get_params, get_return
 from lcyframe.libs.permissions import Permission
@@ -20,6 +20,7 @@ from lcyframe.libs.permissions import Permission
 
 class BaseHandler(RequestHandler):
     __structure__ = {}
+    logging = logging
     app_config = {}
     model = None
     mongo = None
@@ -101,13 +102,14 @@ class BaseHandler(RequestHandler):
 
             logging.error("异常时间：" + self.utils.int_to_date_string(self.utils.now(), "%Y-%m-%d %H:%M:%S"))
             if not hasattr(error, "message"):
-                message = error.args[0] if error.args else "未知错误"
+                message = "%s:%s" % (type(error).__name__, error.args[0]) if error.args else "未知错误"
                 logging.error("异常信息：" + message)
             else:
                 logging.error("异常码：" + str(error.code))
                 logging.error("异常信息：" + error.message)
 
-            logging.error("参数:" + (json.dumps(self.params, ensure_ascii=False) if hasattr(self, "params") else str(self.request.arguments or {})))
+            logging.error("请求地址: %s %.2fms", self.request.uri, 1000.0 * self.request.request_time())
+            logging.error("请求参数: " + (json.dumps(utils.pparams(self.request, self.params), ensure_ascii=False) if hasattr(self, "params") else str(utils.pparams(self.request, self.request.arguments) or {})))
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -120,19 +122,19 @@ class BaseHandler(RequestHandler):
         is_slow_request = request_time > int(self.application.app_config["wsgi"].get("slow_request_time", 1000))
         p = self.params if hasattr(self, "params") else {}
         if is_slow_request:
-            logging.warning("%d %s %.2fms", self.get_status(), self._request_summary(), request_time)
+            logging.warning("[%s] %d %s %.2fms", "慢请求", self.get_status(), self._request_summary(), request_time)
 
         if hasattr(self, "graylog") and self.graylog:
             if self.application.app_config["graylog_config"].get("mode", 0) or is_slow_request:
                 self.graylog.from_server(short_message="OK", code=0, host=self.request.host, request_time=int(request_time), remote_ip=self.request.remote_ip,
-                                         uri=self.request.path, params=p, method=self.request.method)
+                                         uri=self.request.path, params=utils.pparams(self.request, p), method=self.request.method)
         return self.write({"code": 0, "msg": "OK", "data": get_return(self, data or {})})
 
     def write_failed(self, code=1, msg="Error. unknown error", name="HTTP 500"):
         if hasattr(self, "graylog") and self.graylog:
             p = self.params if hasattr(self, "params") else {}
             self.graylog.from_server(short_message=msg, code=code, track=format_exc()[-500:], host=self.request.host, header=self.request.headers._dict,
-                                     remote_ip=self.request.remote_ip, uri=self.request.path, params=p, method=self.request.method)
+                                     remote_ip=self.request.remote_ip, uri=self.request.path, params=utils.pparams(self.request, p), method=self.request.method)
         if name:
             self.write({"code": code, "msg": msg, "name": name, "data": None})
             return
@@ -147,6 +149,10 @@ class BaseHandler(RequestHandler):
         chunk = json.dumps(chunk, ensure_ascii=False)
         return super(BaseHandler, self).write(chunk)
 
+    # def _request_summary(self):
+    #     return "- [%s] %s %s (%s)" % (Copyright.frame_name, self.request.method, self.request.uri,
+    #                            self.request.remote_ip)
+
     def json_callback(self, data):
         """json回调跨域
         """
@@ -226,6 +232,7 @@ class BaseHandler(RequestHandler):
 
 
 class BaseModel(object):
+    logging = logging
     utils = utils
     Permission = None
     api_error = None
@@ -537,11 +544,11 @@ class BaseSchema(object):
             return list(cursor)
 
     @classmethod
-    def distinct(cls, spec, distinct, shard_key_value=None, **kwargs):
+    def distinct(cls, distinct, spec, shard_key_value=None, **kwargs):
         """
         根据spec条件，查询并返回键为distinct的列表，且不重复
         # 返回所有uid的列表，且不重复
-        cls.distinct({"a": 2}, "uid")
+        cls.distinct("uid", {"a": 2})
         [2, 4]
 
         example:
@@ -765,7 +772,7 @@ class BaseSchema(object):
         cursor = cls.find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
         data_list = [cls._parse_data(cls.__parse_oid(d)) for d in list(cls.__meta_cursor(cursor, page, count, sort)) if d]
         total_page = cls.__get_total_page(cursor, count)
-        return data_list, total_page
+        return data_list, total_page, cursor.count()
 
     @classmethod
     def find_list_by_last_id(cls, spec, count=10, sort={"create_at": -1}, fields=False, last_id_field=False, shard_key_value=None):
