@@ -4,7 +4,7 @@ import logging
 import random
 import time
 from datetime import datetime, date
-import zlib, hmac
+import zlib, hmac, urllib
 from bson import BSON, ObjectId
 from functools import wraps
 from lcyframe.libs import utils, funts, cprint, JWT, aes, Rsa, errors
@@ -36,7 +36,8 @@ def get_imge_url(host, img, path=None):
     else:
         host = "http://" + host
 
-    p = os.path.join(host, path, img)
+    safe_params = os.path.join(path, img)
+    p = os.path.join(host, urllib.parse.quote(safe_params, safe='/', encoding=None, errors=None))
     return p
 
 
