@@ -277,7 +277,7 @@ def parse_vals(response_key, response, definition):
         except Exception as exc:
             e = errors.ErrorResponse()
             e.message = "KEY '%s' type is Error in Reference .yml response definition! error.message=%s" % (
-                response_key, exc.message)
+                response_key, exc.args[0])
             logging.warning("=== response_key: %s, response: %s ===" % (response_key, response))
             raise e
 
